vcl/source/treelist/treelistbox.cxx |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

New commits:
commit f28ef77210b1a3cc737689c7a4ae099419cb0493
Author:     Caolán McNamara <caol...@redhat.com>
AuthorDate: Sat Nov 27 16:49:46 2021 +0000
Commit:     Caolán McNamara <caol...@redhat.com>
CommitDate: Sat Nov 27 21:10:15 2021 +0100

    Related: tdf#144410 we don't want a gap in a multicol spanning separator
    
    we would need another column to show a drop down indicator, and we don't
    want the separators to have a visible gap in that case
    
    Change-Id: Ib45b4cda41a09b631f3ea4d4427a8073a9e243d6
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/125947
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caol...@redhat.com>

diff --git a/vcl/source/treelist/treelistbox.cxx 
b/vcl/source/treelist/treelistbox.cxx
index d1658582c5af..58a1a006d72e 100644
--- a/vcl/source/treelist/treelistbox.cxx
+++ b/vcl/source/treelist/treelistbox.cxx
@@ -2588,6 +2588,7 @@ void SvTreeListBox::PaintEntry1(SvTreeListEntry& rEntry, 
tools::Long nLine, vcl:
     Size aRectSize(0, nTempEntryHeight);
 
     SvViewDataEntry* pViewDataEntry = GetViewDataEntry( &rEntry );
+    const bool bSeparator(rEntry.GetFlags() & SvTLEntryFlags::IS_SEPARATOR);
 
     const size_t nTabCount = aTabs.size();
     const size_t nItemCount = rEntry.ItemCount();
@@ -2720,8 +2721,8 @@ void SvTreeListBox::PaintEntry1(SvTreeListEntry& rEntry, 
tools::Long nLine, vcl:
 
         rItem.Paint(aEntryPos, *this, rRenderContext, pViewDataEntry, rEntry);
 
-        // division line between tabs
-        if (pNextTab && rItem.GetType() == SvLBoxItemType::String &&
+        // division line between tabs (but not if this is a separator line)
+        if (!bSeparator && pNextTab && rItem.GetType() == 
SvLBoxItemType::String &&
             // not at the right edge of the window!
             aRect.Right() < nMaxRight)
         {

Reply via email to